@@ -97,4 +97,12 @@ inline XxFln XxBuffer::getDisplayLineNo( const XxFln fline ) const
    return _dpyLineNos[ fline ];
 }
 
+//------------------------------------------------------------------------------
+//
+inline const char* XxBuffer::getBuffer( uint& size ) const
+{
+   size = _bufferSize;
+   return _buffer;
+}
+
 XX_NAMESPACE_END
