@@ -77,7 +77,7 @@ StringToken kwdList[] = {
 specification, plus you can also use `Maximize' to maximize on startup" },
 
    { "Style", STYLE,
-     "Preferred Qt style, see Qt documentation for more details. The style can
+     "Preferred Qt style, see Qt documentation for more details. The style can \
 otherwise be specified through command-line arguments." },
 
    { "Accel", ACCEL,
@@ -139,8 +139,11 @@ is used to save files." },
    { "VerticalLinePosition", VERTICAL_LINE_POS, 
      "Initial column to draw vertical alignment line." },
 
-   { "ClipboardFormat", CLIPBOARD_FORMAT, 
-     "Format of formatted clipboard text." },
+   { "ClipboardHeaderFormat", CLIPBOARD_HEAD_FORMAT, 
+     "Format of header for selection of text for formatted clipboard text." },
+
+   { "ClipboardLineFormat", CLIPBOARD_LINE_FORMAT, 
+     "Format of each selection line for formatted clipboard text." },
 
    { "HorizontalDiffType", HORDIFF_TYPE,
      "Type of horizontal diffs display.  Can be one of \
@@ -189,8 +192,13 @@ StringToken boolkwdList[] = {
    { "IgnoreHorizontalWhitespace", IGNORE_HORIZONTAL_WS, 
      "Ignore horizontal whitespace in horizontal diffs." },
 
+   { "IgnorePerHunkWhitespace", IGNORE_PERHUNK_WS, 
+     "For each hunk, ignore hunk if there are only whitespace and line break \
+changes within that hunk. This can be useful for ignoring code reformatting \
+for certain source code languages that allow it (e.g. C++)." },
+
    { "FormatClipboardText", FORMAT_CLIPBOARD_TEXT, 
-     "Enables clipboard (copy-paste) formatting.  If disable, text that goes \
+     "Enables clipboard (copy-paste) formatting.  If disabled, text that goes \
 in the clipboard is simply left unformatted." },
 
    { "IgnoreErrors", IGNORE_ERRORS,
@@ -202,6 +210,11 @@ in the clipboard is simply left unformatted." },
    { "DisableCursorDisplay", DISABLE_CURSOR_DISPLAY, 
      "Disables displaying the line cursor." },
 
+   { "DrawPatternInFillerLines", DRAW_PATTERN_IN_FILLER_LINES, 
+     "Some people like to have a pattern drawn for filler lines to make it \
+really dead obvious that they are not real lines, but just inserted for \
+display purpose. This setting enables it." },
+
    { "HideCarriageReturns", HIDE_CR, 
      "Hides CR characters found in files created under DOS/Windows." },
 
@@ -237,10 +250,12 @@ XxBoolOpt boolMap[] = {
    BOOL_EXIT_IF_NO_CONFLICTS,
    BOOL_SELECT_MERGE,
    BOOL_IGNORE_HORIZONTAL_WS,
+   BOOL_IGNORE_PERHUNK_WS,
    BOOL_FORMAT_CLIPBOARD_TEXT,
    BOOL_IGNORE_ERRORS,
    BOOL_WARN_ABOUT_UNSAVED,
    BOOL_DISABLE_CURSOR_DISPLAY,
+   BOOL_DRAW_PATTERN_IN_FILLER_LINES,
    BOOL_HIDE_CR,
    BOOL_DIRDIFF_IGNORE_FILE_CHANGES,
    BOOL_DIRDIFF_BUILD_FROM_OUTPUT,
@@ -337,6 +352,7 @@ StringToken accelList[] = {
    { "HorizontalDiffSingle", ACCEL_HORDIFF_SINGLE, 0 },
    { "HorizontalDiffMultiple", ACCEL_HORDIFF_MULTIPLE, 0 },
    { "ToggleIgnoreHorizontalWhitespace", ACCEL_TOGGLE_IGNORE_HORIZONTAL_WS, 0 },
+   { "ToggleIgnorePerHunkWhitespace", ACCEL_TOGGLE_IGNORE_PERHUNK_WS, 0 },
    { "ToggleFormatClipboardText", ACCEL_TOGGLE_FORMAT_CLIPBOARD_TEXT, 0 },
    { "IgnoreFileNone", ACCEL_IGNORE_FILE_NONE, 0 },
    { "IgnoreFileLeft", ACCEL_IGNORE_FILE_LEFT, 0 },
@@ -450,7 +466,9 @@ StringToken colorList[] = {
    { "Cursor", COLOR_CURSOR,
      " Line cursor color " },
    { "VerticalLine", COLOR_VERTICAL_LINE,
-     " Vertical line color " }
+     " Vertical line color " },
+   { "TextSelection", COLOR_TEXT_SELECTION,
+     " Color of text region selection " }
 };
 
 StringToken commandList[] = {
@@ -1178,9 +1196,15 @@ void XxResParser::genInitFile(
       }
    }
 
-   if ( res1.getClipboardFormat() != res2.getClipboardFormat() ) {
-      os << searchTokenName( STPARAM(kwdList), CLIPBOARD_FORMAT ) << ": \""
-         << res1.getClipboardFormat() << "\"" << endl;
+   if ( res1.getClipboardHeadFormat() !=
+        res2.getClipboardHeadFormat() ) {
+      os << searchTokenName( STPARAM(kwdList), CLIPBOARD_HEAD_FORMAT ) << ": \""
+         << res1.getClipboardHeadFormat() << "\"" << endl;
+   }
+   if ( res1.getClipboardLineFormat() !=
+        res2.getClipboardLineFormat() ) {
+      os << searchTokenName( STPARAM(kwdList), CLIPBOARD_LINE_FORMAT ) << ": \""
+         << res1.getClipboardLineFormat() << "\"" << endl;
    }
 
    if ( res1.getHordiffType() != res2.getHordiffType() ) {
@@ -1326,8 +1350,10 @@ void XxResParser::listResources( QTextStream& os )
          << b1.latin1() << "\"" << endl;
    }
 
-   os << searchTokenName( STPARAM(kwdList), CLIPBOARD_FORMAT ) << ": \""
-      << res.getClipboardFormat() << "\"" << endl;
+   os << searchTokenName( STPARAM(kwdList), CLIPBOARD_HEAD_FORMAT ) << ": \""
+      << res.getClipboardHeadFormat() << "\"" << endl;
+   os << searchTokenName( STPARAM(kwdList), CLIPBOARD_LINE_FORMAT ) << ": \""
+      << res.getClipboardLineFormat() << "\"" << endl;
 
    const char* hdtstr[3] = { "None", "Single", "Multiple" };
    os << searchTokenName( STPARAM(kwdList), HORDIFF_TYPE ) << ": "
@@ -1668,8 +1694,19 @@ QString XxResParser::getResourceRef()
    {
       drbegin( os );
       const StringToken* tok =
-         searchToken( STPARAM(kwdList), CLIPBOARD_FORMAT );
-      QString cf = XxHelp::xmlize( res.getClipboardFormat() );
+         searchToken( STPARAM(kwdList), CLIPBOARD_HEAD_FORMAT );
+      QString cf = XxHelp::xmlize( res.getClipboardHeadFormat() );
+      os << tok->_name << ": \"" << cf << "\"" << endl;
+      drend( os );
+      ddbegin( os );
+      os << tok->_desc << endl;
+      ddend( os );
+   }
+   {
+      drbegin( os );
+      const StringToken* tok =
+         searchToken( STPARAM(kwdList), CLIPBOARD_LINE_FORMAT );
+      QString cf = XxHelp::xmlize( res.getClipboardLineFormat() );
       os << tok->_name << ": \"" << cf << "\"" << endl;
       drend( os );
       ddbegin( os );
