@@ -1,8 +1,8 @@
+/* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $Id: util.h,v 1.25 2002/02/25 00:17:30 blais Exp $
- * $Date: 2002/02/25 00:17:30 $
+ * $RCSfile: util.h,v $
  *
- * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
+ * Copyright (C) 1999-2002  Martin Blais <blais@iro.umontreal.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ public:
    // processing by our program.  Return true on success.
    static bool testFile(
       const QString& filename,
-      const bool     testAscii,
+      bool           testAscii,
       bool&          isDirectory
    );
 
