@@ -1,8 +1,8 @@
+/* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $Id: version.c,v 1.1 2001/11/16 00:55:15 blais Exp $
- * $Date: 2001/11/16 00:55:15 $
+ * $RCSfile: version.c,v $
  *
- * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
+ * Copyright (C) 1999-2002  Martin Blais <blais@iro.umontreal.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,5 +30,10 @@
  * PUBLIC DECLARATIONS
  *============================================================================*/
 
+char const xx_name[] = "xxdiff";
 char const xx_version[] = XX_VERSION;
+char const xx_description[] = "A graphical file comparator and merge tool.";
+char const xx_copyright[] = "Copyright (C) 1999-2002  Martin Blais";
+char const xx_homepage[] = "http://xxdiff.sourceforge.net";
+char const xx_bugs_email[] = "blais@iro.umontreal.ca";
 
